--- old/usr/src/uts/common/fs/zfs/txg.c	2013-04-23 14:09:37.747636866 -0600
+++ new/usr/src/uts/common/fs/zfs/txg.c	2013-04-23 14:09:37.757421862 -0600
@@ -337,6 +337,14 @@
 	th->th_cpu = NULL;	/* defensive */
 }
 
+/*
+ * Quiesce, v.: to render temporarily inactive or disabled
+ *
+ * Blocks until all transactions in the group are committed.
+ *
+ * On return, the transaction group has reached a stable state in which it can
+ * then be passed off to the syncing context.
+ */
 static void
 txg_quiesce(dsl_pool_t *dp, uint64_t txg)
 {
@@ -387,6 +395,9 @@
 
 /*
  * Dispatch the commit callbacks registered on this txg to worker threads.
+ *
+ * If no callbacks are registered for a given TXG, nothing happens.
+ * This function creates a taskq for the associated pool, if needed.
  */
 static void
 txg_dispatch_callbacks(dsl_pool_t *dp, uint64_t txg)
@@ -397,7 +408,10 @@
 
 	for (c = 0; c < max_ncpus; c++) {
 		tx_cpu_t *tc = &tx->tx_cpu[c];
-		/* No need to lock tx_cpu_t at this point */
+		/*
+		 * No need to lock tx_cpu_t at this point, since this can
+		 * only be called once a txg has been synced.
+		 */
 
 		int g = txg & TXG_MASK;
 
